@@ -31,9 +31,8 @@ describe 'cinder::api' do
         is_expected.to contain_cinder_config('DEFAULT/osapi_volume_workers').with(
          :value => '8'
         )
-        is_expected.to contain_cinder_config('DEFAULT/nova_catalog_info').with(
-         :value => 'compute:Compute Service:publicURL'
-        )
+        # nova_catalog_info has been deprecated
+        is_expected.not_to contain_cinder_config('DEFAULT/nova_catalog_info')
         is_expected.to contain_cinder_config('DEFAULT/default_volume_type').with(
          :value => '<SERVICE DEFAULT>'
         )
@@ -53,10 +52,6 @@ describe 'cinder::api' do
          :value => 'keystone'
         )
 
-        is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_name').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_password').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_tenant').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_auth_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('key_manager/backend').with_value('cinder.keymgr.conf_key_mgr.ConfKeyManager')
         is_expected.to contain_cinder_config('barbican/barbican_endpoint').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('barbican/auth_endpoint').with_value('<SERVICE DEFAULT>')
@@ -67,13 +62,24 @@ describe 'cinder::api' do
       end
     end
 
-    describe 'with a custom nova_catalog params' do
+    describe 'with deprecated parameters' do
       let :params do
         req_params.merge({
-          'nova_catalog_info'       => 'compute:nova:publicURL',
+          'nova_catalog_info'           => 'compute:nova:publicURL',
+          'os_privileged_user_name'     => 'admin',
+          'os_privileged_user_password' => 'password',
+          'os_privileged_user_tenant'   => 'admin',
+          'os_privileged_user_auth_url' => 'http://localhost:8080',
         })
       end
-      it { is_expected.to contain_cinder_config('DEFAULT/nova_catalog_info').with_value('compute:nova:publicURL') }
+      it 'should not add them to the config' do
+        is_expected.not_to contain_cinder_config('DEFAULT/nova_catalog_info')
+        is_expected.not_to contain_cinder_config('DEFAULT/os_privileged_user_name')
+        is_expected.not_to contain_cinder_config('DEFAULT/os_privileged_user_password')
+        is_expected.not_to contain_cinder_config('DEFAULT/os_privileged_user_tenant')
+        is_expected.not_to contain_cinder_config('DEFAULT/os_privileged_user_auth_url')
+
+      end
     end
 
     describe 'with a custom region for nova' do
@@ -98,75 +104,6 @@ describe 'cinder::api' do
       end
     end
 
-    describe 'with an OpenStack privileged account' do
-
-      context 'with all needed params' do
-        let :params do
-          req_params.merge({
-            'privileged_user'             => 'true',
-            'os_privileged_user_name'     => 'admin',
-            'os_privileged_user_password' => 'password',
-            'os_privileged_user_tenant'   => 'admin',
-            'os_privileged_user_auth_url' => 'http://localhost:8080',
-          })
-        end
-
-        it { is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_name').with_value('admin') }
-        it { is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_password').with_value('password') }
-        it { is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_tenant').with_value('admin') }
-        it { is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_auth_url').with_value('http://localhost:8080') }
-      end
-
-      context 'without os_privileged_user_auth_url' do
-        let :params do
-          req_params.merge({
-            'privileged_user'             => 'true',
-            'os_privileged_user_name'     => 'admin',
-            'os_privileged_user_password' => 'password',
-            'os_privileged_user_tenant'   => 'admin',
-          })
-        end
-
-        it { is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_name').with_value('admin') }
-        it { is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_password').with_value('password') }
-        it { is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_tenant').with_value('admin') }
-        it { is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_auth_url').with_value('<SERVICE DEFAULT>') }
-      end
-
-      context 'without os_privileged_user' do
-        let :params do
-          req_params.merge({
-            'privileged_user' => 'true',
-          })
-        end
-
-        it_raises 'a Puppet::Error', /The os_privileged_user_name parameter is required when privileged_user is set to true/
-      end
-
-      context 'without os_privileged_user_password' do
-        let :params do
-          req_params.merge({
-            'privileged_user'         => 'true',
-            'os_privileged_user_name' => 'admin',
-          })
-        end
-
-        it_raises 'a Puppet::Error', /The os_privileged_user_password parameter is required when privileged_user is set to true/
-      end
-
-      context 'without os_privileged_user_tenant' do
-        let :params do
-          req_params.merge({
-            'privileged_user'             => 'true',
-            'os_privileged_user_name'     => 'admin',
-            'os_privileged_user_password' => 'password',
-          })
-        end
-
-        it_raises 'a Puppet::Error', /The os_privileged_user_tenant parameter is required when privileged_user is set to true/
-      end
-    end
-
     describe 'with a default volume type' do
       let :params do
         req_params.merge({'default_volume_type' => 'foo'})
@@ -255,19 +192,6 @@ describe 'cinder::api' do
       )}
     end
 
-    describe 'while validating the service with custom command' do
-      let :params do
-        req_params.merge({
-          :validate           => true,
-          :validation_options => { 'cinder-api' => { 'command' => 'my-script' } }
-        })
-      end
-      it { is_expected.to contain_openstacklib__service_validation('cinder-api').with(
-        :command   => 'my-script',
-        :subscribe => 'Service[cinder-api]',
-      )}
-    end
-
     describe 'with a custom auth_strategy' do
       let :params do
         req_params.merge({'auth_strategy' => 'noauth'})
@@ -296,7 +220,7 @@ describe 'cinder::api' do
 
       let :pre_condition do
         "include ::apache
-         class { 'cinder': rabbit_password => 'secret' }
+         class { 'cinder': }
          class { '::cinder::keystone::authtoken':
            password => 'foo',
          }"
@@ -318,7 +242,7 @@ describe 'cinder::api' do
 
       let :pre_condition do
         "include ::apache
-         class { 'cinder': rabbit_password => 'secret' }
+         class { 'cinder': }
          class { '::cinder::keystone::authtoken':
            password => 'foo',
          }"
